Creates a list of arrays. These are used to store the summary, abundance
and density outputs of the dht routine called from mrds.
create.result.arrays(species.name, species.code.definitions, region.table,
clusters, n)a list of all the species in the analysis
a list with an element for each unidentified code which contains a vector of corresponding identified species codes or NULL if not required
dataframe of region records - Region.Label and Area
boolean, TRUE if observations are of cluster, FALSE if observations are of individuals.
the number of bootstrap iterations to be completed.
list of arrays